#!/bin/bash


wah_error() {
    >&2 echo "$1"
    exit 1
}


# This script assumes that the dhclient startup command from the inet.defn file
# of the ifupdown package has the following format:
# dhclient -4 -v -pf /run/dhclient.%iface%.pid \
#       -lf /var/lib/dhcp/dhclient.%iface%.leases -I \
#       -df /var/lib/dhcp/dhclient6.%iface%.leases %iface%

wah_restart_dhclient() {
    local iface=$1
    local dhclient_pidfile="/run/dhclient.$iface.pid"

    # Check if there's a PID file for iface and its owner is root.

    [[ `stat -c %U "$dhclient_pidfile"` == "root" ]] || return 1

    local dhclient_pid=`cat "$dhclient_pidfile"`
    local dhclient_cmdline=`cat "/proc/$dhclient_pid/cmdline" | tr '\0' ' '`

    # We restart dhclient using the same cmdline it was exec'ed with,
    # so we have validate it.

    if [[ -z $dhclient_cmdline ]] \
        || [[ ! $dhclient_cmdline =~ ^dhclient ]]; then

        return 1
    fi

    dhclient -r -pf "$dhclient_pidfile" "$iface"
    $dhclient_cmdline
}


[[ $# -eq 2 ]] || wah_error "usage: $0 IFACE ACTION"

IFACE=$1
ACTION=$2

echo "$0 '$IFACE' '$ACTION'"

if [[ $ACTION == "CONNECTED" ]]; then
    wah_restart_dhclient "$IFACE"
fi

exit 0
